@@ -1,6 +1,6 @@
 
 /*
- *  $Id: autoopts.c,v 3.10 2002/05/24 01:44:42 bkorb Exp $
+ *  $Id: autoopts.c,v 2.47 2002/08/10 19:28:28 bkorb Exp $
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -72,15 +72,12 @@
 #include "autoopts.h"
 #include "compat/compat.h"
 
+#ifndef HAVE_PATHFIND
+#  include "compat/pathfind.c"
+#endif
 
 #define ISNAMECHAR( c )    (isalnum(c) || ((c) == '_') || ((c) == '-'))
 
-tSCC zBadVer[] = "Automated Options Processing Error!\n\
-\t%s called optionProcess with structure version %d.%d.%d.\n\
-\tThis library was compiled with version %d.%d.%d\n\
-\tand requires a minimum structure version of %d.%d.%d\n";
-
-
 tSCC zMisArg[]      = "%s: option `%s' requires an argument\n";
 tSCC zNoArg[]       = "%s: option `%s' cannot have an argument\n";
 tSCC zIllOptChr[]   = "%s: illegal option -- %c\n";
@@ -779,14 +776,46 @@ doImmediateOpts( pOpts )
      *     either too large (?!) or too small,
      *  THEN emit error message and fail-exit
      */
-    if (  ( pOpts->structVersion  != OPTIONS_STRUCT_VERSION )
-       && (  (pOpts->structVersion > OPTIONS_STRUCT_VERSION )
-          || (pOpts->structVersion < MIN_OPTION_VERSION     )
+    if (  ( pOpts->structVersion  != OPTIONS_STRUCT_VERSION  )
+       && (  (pOpts->structVersion > OPTIONS_STRUCT_VERSION  )
+          || (pOpts->structVersion < OPTIONS_MINIMUM_VERSION )
        )  )  {
-        fprintf( stderr, zBadVer, pOpts->origArgVect[0],
-                 NUM_TO_VER( pOpts->structVersion ),
-                 NUM_TO_VER( OPTIONS_STRUCT_VERSION ),
-                 NUM_TO_VER( MIN_OPTION_VERSION ));
+#if  defined( __STDC__ ) || defined( __cplusplus )
+        tSCC zErr[] =
+            "Automated Options Processing Error!\n"
+            "\t%s called optionProcess with structure version %d:%d:%d.\n";
+        tSCC zBig[] =
+            "\tThis exceeds the compiled library version:  "
+            OPTIONS_VERSION_STRING "\n";
+        tSCC zSml[] =
+            "\tThis is less than the minimum library version:  "
+            OPTIONS_MIN_VER_STRING "\n";
+
+        fprintf( stderr, zErr, pOpts->origArgVect[0],
+                 NUM_TO_VER( pOpts->structVersion ));
+        if (pOpts->structVersion > OPTIONS_STRUCT_VERSION )
+            fputs( zBig, stderr );
+        else
+            fputs( zSml, stderr );
+#else
+        tSCC zErr[] =
+            "Automated Options Processing Error!\n";
+        tSCC zVer[] =
+            "\t%s called optionProcess with structure version %d:%d:%d.\n";
+        tSCC zBig[] =
+            "\tThis exceeds the compiled library version:  %s\n";
+        tSCC zSml[] =
+            "\tThis is less than the minimum library version: %s\n";
+
+        fputs( zErr, stderr );
+        fprintf( stderr, zVer, pOpts->origArgVect[0],
+                 NUM_TO_VER( pOpts->structVersion ));
+        if (pOpts->structVersion > OPTIONS_STRUCT_VERSION )
+            fprintf( stderr, zBig, OPTIONS_VERSION_STRING );
+        else
+            fprintf( stderr, zSml, OPTIONS_MIN_VER_STRING );
+#endif
+
         exit( EXIT_FAILURE );
     }
 
